@@ -11,9 +11,9 @@ class Mensagem(core.models.Log):
     :Edições:
     """
     nome = models.CharField(max_length=200, primary_key=True)
-    nm_descritivo = models.CharField(max_length=200, null=True)
-    conteudo = models.TextField(null=True)
-    variaveis = models.TextField(null=True)
+    nm_descritivo = models.CharField(max_length=200, null=True, blank=True)
+    conteudo = models.TextField(null=True, blank=True)
+    variaveis = models.TextField(null=True, blank=True)
 
     class Meta(core.models.Log.Meta):
         abstract = False
@@ -30,9 +30,9 @@ class MensagemLog(core.models.Log):
     :Criação: Nícolas Marinoni Grande - 17/08/2020
     :Edições:
     """
-    mensagem = models.ForeignKey('Mensagem', on_delete=models.DO_NOTHING, null=True)
-    destinatario = models.CharField(max_length=200, null=True)
-    retorno = models.TextField(null=True)
+    mensagem = models.ForeignKey('Mensagem', on_delete=models.DO_NOTHING, null=True, blank=True)
+    destinatario = models.CharField(max_length=200, null=True, blank=True)
+    retorno = models.TextField(null=True, blank=True)
 
     class Meta(core.models.Log.Meta):
         abstract = False
